@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2009 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -597,14 +597,14 @@ filter_reset (GMimeFilter *filter)
  *
  * Creates a new GMimeFilterEnriched object.
  *
- * Returns a new GMimeFilter object.
+ * Returns: a new GMimeFilter object.
  **/
 GMimeFilter *
 g_mime_filter_enriched_new (guint32 flags)
 {
 	GMimeFilterEnriched *new;
 	
-	new = (GMimeFilterEnriched *) g_object_new (GMIME_TYPE_FILTER_ENRICHED, NULL);
+	new = g_object_newv (GMIME_TYPE_FILTER_ENRICHED, 0, NULL);
 	new->flags = flags;
 	
 	return (GMimeFilter *) new;
