@@ -479,7 +479,7 @@ g_mime_filter_gzip_new (GMimeFilterGZipMode mode, int level)
 	GMimeFilterGZip *new;
 	int retval;
 	
-	new = g_object_new (GMIME_TYPE_FILTER_GZIP, NULL);
+	new = g_object_newv (GMIME_TYPE_FILTER_GZIP, 0, NULL);
 	new->mode = mode;
 	new->level = level;
 	
